==> cpsi-react-web-component-app-0.4.0.tgz: package/src/index.tsx <==
import './index.css';
import App from './App';
import reportWebVitals from './reportWebVitals';
import React, { FunctionComponent, useEffect } from 'react';
import * as ReactDOM from 'react-dom/client';
import Checklist from './components/CardComponent';
import ComingSoonAndPastCard from './components/ComingSoonAndPastCardComponent';
import r2wc from "@r2wc/react-to-web-component";
import reactToWebComponent from "react-to-webcomponent";

const WebComponentWrapper: FunctionComponent<{ header: string, opendate: string, duedate: string, closedate: string, description: string }> = ({ header, opendate, duedate, closedate, description }) => {
    useEffect(() => {
        console.log('header: ', header);
        console.log('opendate: ', opendate);
        console.log('duedate: ', duedate);
        console.log('closedate: ', closedate);
        console.log('description: ', description);
    }, [header, opendate, duedate, closedate, description]);
    return (
        <Checklist header={header} opendate={opendate} duedate={duedate} closedate={closedate} description={description} />
    );
}
const wcChecklist = r2wc(WebComponentWrapper, {
    props: {
        header: 'string',
        opendate: 'string',
        duedate: 'string',
        closedate: 'string',
        description: 'string'
    },
});
customElements.define('custom-app-card', wcChecklist);

const WebComponentComingSoonAndPastCard: FunctionComponent<{ header: string, datetype: string, date: string, color: string, description: string, headingLogo: string }> = ({ header, datetype, date, color, description, headingLogo }) => {
    useEffect(() => {
        console.log('header: ', header);
        console.log('datetype: ', datetype);
        console.log('date: ', date);
        console.log('color: ', color);
        console.log('description: ', description);
        console.log('headingLogo: ', headingLogo)
    }, [header, datetype, date, color, description, headingLogo]);
    return (
        <ComingSoonAndPastCard header={header} datetype={datetype} date={date} color={color} description={description} headingLogo={headingLogo} />
    );
}
const wcComingSoonAndPastCardList = r2wc(WebComponentComingSoonAndPastCard, {
    props: {
        header: 'string',
        datetype: 'string',
        date: 'string',
        color: 'string',
        description: 'string',
        headingLogo:'string'
    },
});
customElements.define('coming-soon-and-past-card', wcComingSoonAndPastCardList);

==> cpsi-react-web-component-app-0.5.0.tgz: package/src/index.tsx <==
import './index.css';
import App from './App';
import reportWebVitals from './reportWebVitals';
import React, { FunctionComponent, useEffect } from 'react';
import * as ReactDOM from 'react-dom/client';
import Checklist from './components/CardComponent';
import ComingSoonAndPastCard from './components/ComingSoonAndPastCardComponent';
import r2wc from "@r2wc/react-to-web-component";
import reactToWebComponent from "react-to-webcomponent";

const WebComponentWrapper: FunctionComponent<{ header: string, opendate: string, duedate: string, closedate: string, description: string }> = ({ header, opendate, duedate, closedate, description }) => {
    useEffect(() => {
        console.log('header: ', header);
        console.log('opendate: ', opendate);
        console.log('duedate: ', duedate);
        console.log('closedate: ', closedate);
        console.log('description: ', description);
    }, [header, opendate, duedate, closedate, description]);
    return (
        <Checklist header={header} opendate={opendate} duedate={duedate} closedate={closedate} description={description} />
    );
}
const wcChecklist = r2wc(WebComponentWrapper, {
    props: {
        header: 'string',
        opendate: 'string',
        duedate: 'string',
        closedate: 'string',
        description: 'string'
    },
});
customElements.define('custom-app-card', wcChecklist);

const WebComponentComingSoonAndPastCard: FunctionComponent<{ header: string, datetype: string, date: string, color: string, description: string }> = ({ header, datetype, date, color, description }) => {
    useEffect(() => {
        console.log('header: ', header);
        console.log('datetype: ', datetype);
        console.log('date: ', date);
        console.log('color: ', color);
        console.log('description: ', description);
    }, [header, datetype, date, color, description]);
    return (
        <ComingSoonAndPastCard header={header} datetype={datetype} date={date} color={color} description={description} />
    );
}
const wcComingSoonAndPastCardList = r2wc(WebComponentComingSoonAndPastCard, {
    props: {
        header: 'string',
        datetype: 'string',
        date: 'string',
        color: 'string',
        description: 'string'
    },
});
customElements.define('coming-soon-and-past-card', wcComingSoonAndPastCardList);
